@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: vault
-version: 0.3.0.5
-id: vault-0.3.0.5-102b362b61d24705a338afb76b200480
-key: vault_3zyMoVn9cRoFibzDYkCcGU
+version: 0.3.0.6
+id: vault-0.3.0.6-8b1ddbd07c6eb1be1ee9aee781649e3c
+key: vault_6a139yu66oWGEEnx8egA4x
 license: BSD3
 copyright: (c) Heinrich Apfelmus 2011-2013
 maintainer: Heinrich Apfelmus <apfelmus at quantentunnel de>
@@ -25,15 +25,15 @@ exposed-modules:
     Data.Vault.Lazy Data.Vault.Strict Data.Vault.ST.Lazy
     Data.Vault.ST.Strict Data.Unique.Really
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/vault-0.3.0.5
-library-dirs: /usr/lib/ghc-7.10.3/site-local/vault-0.3.0.5
-data-dir: /usr/share/arm-linux-ghc-7.10.3/vault-0.3.0.5
-hs-libraries: HSvault-0.3.0.5-3zyMoVn9cRoFibzDYkCcGU
+import-dirs: /usr/lib/ghc-7.10.3/site-local/vault-0.3.0.6
+library-dirs: /usr/lib/ghc-7.10.3/site-local/vault-0.3.0.6
+data-dir: /usr/share/arm-linux-ghc-7.10.3/vault-0.3.0.6
+hs-libraries: HSvault-0.3.0.6-6a139yu66oWGEEnx8egA4x
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
-    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
+    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
 haddock-interfaces: /usr/share/doc/haskell-vault/html/vault.haddock
 haddock-html: /usr/share/doc/haskell-vault/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
